"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var http_1 = require("@angular/common/http");
var rxjs_1 = require("rxjs");
var operators_1 = require("rxjs/operators");
var core_1 = require("@angular/core");
var http_utils_1 = require("nativescript-angular/http-client/http-utils");
var nativescript_angular_1 = require("nativescript-angular");
var excluded_service_1 = require("./excluded.service");
var ssl_pinning_1 = require("../ssl-pinning");
var SslPinningHttpXhrBackend = (function (_super) {
    __extends(SslPinningHttpXhrBackend, _super);
    function SslPinningHttpXhrBackend(xhrFactory, nsFileSystem, excludedService) {
        var _this = _super.call(this, xhrFactory) || this;
        _this.nsFileSystem = nsFileSystem;
        _this.excludedService = excludedService;
        return _this;
    }
    SslPinningHttpXhrBackend.prototype.handle = function (req) {
        if (http_utils_1.isLocalRequest(req.url)) {
            return this.handleLocalFileRequest(req.url);
        }
        if (this.excludedService.skipSSLPinning(req)) {
            return _super.prototype.handle.call(this, req);
        }
        return request(req).pipe(operators_1.map(function (resp) {
            return new http_1.HttpResponse({
                body: resp.content,
                headers: new http_1.HttpHeaders(resp.headers),
                status: resp.statusCode,
                statusText: resp.reason,
                url: req.url
            });
        }), operators_1.catchError(function (error) {
            return rxjs_1.throwError(new http_1.HttpErrorResponse({
                status: error.status,
                headers: error.headers,
                statusText: error.statusText,
                url: req.url
            }));
        }));
    };
    SslPinningHttpXhrBackend.prototype.handleLocalFileRequest = function (url) {
        return http_utils_1.processLocalFileRequest(url, this.nsFileSystem, createSuccessResponse, createErrorResponse);
    };
    SslPinningHttpXhrBackend = __decorate([
        core_1.Injectable(),
        __metadata("design:paramtypes", [http_1.XhrFactory, nativescript_angular_1.NSFileSystem, excluded_service_1.ExcludedService])
    ], SslPinningHttpXhrBackend);
    return SslPinningHttpXhrBackend;
}(http_1.HttpXhrBackend));
exports.SslPinningHttpXhrBackend = SslPinningHttpXhrBackend;
function request(req) {
    var method = req.method;
    return rxjs_1.from(ssl_pinning_1.SslPinning.request({
        url: req.url,
        body: req.body,
        method: method,
        headers: mapHeaders(req),
        allowLargeResponse: true
    }));
}
exports.request = request;
function mapHeaders(req) {
    var headers = {};
    req.headers.keys().forEach(function (key) {
        headers[key] = req.headers.getAll(key).join(' ');
    });
    if (Object.keys(headers).length) {
        return headers;
    }
    return {
        'Content-Type': 'application/json',
        'Accept': 'application/json'
    };
}
exports.mapHeaders = mapHeaders;
function createSuccessResponse(url, body, status) {
    return new http_1.HttpResponse({
        url: url,
        body: body,
        status: status,
        statusText: 'OK'
    });
}
function createErrorResponse(url, body, status) {
    return new http_1.HttpErrorResponse({
        url: url,
        error: body,
        status: status,
        statusText: 'ERROR'
    });
}
//# sourceMappingURL=ssl-pinning-http-xhr.backend.js.map