"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var ssl_pinning_common_1 = require("./ssl-pinning.common");
var types_1 = require("tns-core-modules/utils/types");
var policies = {
    def: AFSecurityPolicy.defaultPolicy(),
    secured: false,
};
policies.def.allowInvalidCertificates = true;
policies.def.validatesDomainName = false;
var SslPinning = (function (_super) {
    __extends(SslPinning, _super);
    function SslPinning() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    SslPinning.enableSSLPinning = function (options) {
        if (!policies.secure) {
            policies.secure = AFSecurityPolicy.policyWithPinningMode(1);
            policies.secure.allowInvalidCertificates = (types_1.isDefined(options.allowInvalidCertificates)) ? options.allowInvalidCertificates : false;
            policies.secure.validatesDomainName = (types_1.isDefined(options.validatesDomainName)) ? options.validatesDomainName : true;
            var data = NSData.dataWithContentsOfFile(options.certificate);
            policies.secure.pinnedCertificates = NSSet.setWithObject(data);
        }
        policies.secured = true;
        console.log('nativescript-ssl-pinning > Enabled SSL pinning');
    };
    SslPinning.disableSSLPinning = function () {
        policies.secured = false;
        console.log('nativescript-ssl-pinning > Disabled SSL pinning');
    };
    SslPinning.AFSuccess = function (resolve, task, data) {
        var content;
        if (data && data.class) {
            if (data.enumerateKeysAndObjectsUsingBlock || data.class().name === 'NSArray') {
                var serial = NSJSONSerialization.dataWithJSONObjectOptionsError(data, 1);
                content = NSString.alloc().initWithDataEncoding(serial, NSUTF8StringEncoding).toString();
            }
            else if (data.class().name === 'NSData') {
                content = NSString.alloc().initWithDataEncoding(data, NSASCIIStringEncoding).toString();
            }
            else {
                content = data;
            }
            try {
                content = JSON.parse(content);
            }
            catch (e) {
            }
        }
        else {
            content = data;
        }
        resolve({ task: task, content: content });
    };
    SslPinning.AFFailure = function (resolve, reject, task, error) {
        var data = error.userInfo.valueForKey(AFNetworkingOperationFailingURLResponseDataErrorKey);
        var body = NSString.alloc().initWithDataEncoding(data, NSUTF8StringEncoding).toString();
        try {
            body = JSON.parse(body);
        }
        catch (e) {
        }
        var content = {
            body: body,
            description: error.description,
            reason: error.localizedDescription,
            url: error.userInfo.objectForKey('NSErrorFailingURLKey').description
        };
        if (policies.secured === true) {
            content.description = 'nativescript-ssl-pinning > Invalid SSL certificate! ' + content.description;
        }
        var reason = error.localizedDescription;
        reject({ task: task, content: content, reason: reason });
    };
    SslPinning.request = function (opts) {
        return new Promise(function (resolve, reject) {
            try {
                var manager_1 = AFHTTPSessionManager.alloc().initWithBaseURL(NSURL.URLWithString(opts.url));
                if (opts.headers && opts.headers['Content-Type'] === 'application/json') {
                    manager_1.requestSerializer = AFJSONRequestSerializer.serializer();
                    manager_1.responseSerializer = AFJSONResponseSerializer.serializerWithReadingOptions(4);
                }
                else {
                    manager_1.requestSerializer = AFHTTPRequestSerializer.serializer();
                    manager_1.responseSerializer = AFHTTPResponseSerializer.serializer();
                }
                manager_1.requestSerializer.allowsCellularAccess = true;
                manager_1.securityPolicy = (policies.secured === true) ? policies.secure : policies.def;
                manager_1.requestSerializer.timeoutInterval = 10;
                var heads_1 = opts.headers;
                if (heads_1) {
                    Object.keys(heads_1).forEach(function (key) { return manager_1.requestSerializer.setValueForHTTPHeaderField(heads_1[key], key); });
                }
                var dict_1 = null;
                if (opts.body) {
                    var cont_1 = ssl_pinning_common_1.dataObject(opts.body);
                    if (types_1.isObject(cont_1)) {
                        dict_1 = NSMutableDictionary.new();
                        Object.keys(cont_1).forEach(function (key) { return dict_1.setValueForKey(cont_1[key], key); });
                    }
                }
                var headers = null;
                var success = function (task, data) {
                    SslPinning.AFSuccess(resolve, task, data);
                };
                var failure = function (task, error) {
                    SslPinning.AFFailure(resolve, reject, task, error);
                };
                var progress = function (progress) {
                };
                if (opts.method === "GET") {
                    manager_1.GETParametersHeadersProgressSuccessFailure(opts.url, dict_1, headers, progress, success, failure);
                }
                else if (opts.method === "POST") {
                    manager_1.POSTParametersHeadersProgressSuccessFailure(opts.url, dict_1, headers, progress, success, failure);
                }
                else if (opts.method === "PUT") {
                    manager_1.PUTParametersHeadersSuccessFailure(opts.url, dict_1, headers, success, failure);
                }
                else if (opts.method === "DELETE") {
                    manager_1.DELETEParametersHeadersSuccessFailure(opts.url, dict_1, headers, success, failure);
                }
                else if (opts.method === "PATCH") {
                    manager_1.PATCHParametersHeadersSuccessFailure(opts.url, dict_1, headers, success, failure);
                }
                else if (opts.method === "HEAD") {
                    manager_1.HEADParametersHeadersSuccessFailure(opts.url, dict_1, headers, success, failure);
                }
            }
            catch (error) {
                reject(error);
            }
        }).then(function (AFResponse) {
            var sendi = {
                content: AFResponse.content,
                headers: {},
            };
            var response = AFResponse.task.response;
            if (!types_1.isNullOrUndefined(response)) {
                sendi.statusCode = response.statusCode;
                var dict = response.allHeaderFields;
                dict.enumerateKeysAndObjectsUsingBlock(function (k, v) { return sendi.headers[k] = v; });
            }
            return Promise.resolve(sendi);
        }).catch(function (AFResponse) {
            var sendi = {
                content: AFResponse.content,
                headers: {},
                statusText: AFResponse.reason
            };
            var response = AFResponse.task.response;
            if (!types_1.isNullOrUndefined(response)) {
                sendi['status'] = response.statusCode;
                var dict = response.allHeaderFields;
                dict.enumerateKeysAndObjectsUsingBlock(function (k, v) { return sendi.headers[k] = v; });
            }
            return Promise.reject(sendi);
        });
    };
    return SslPinning;
}(ssl_pinning_common_1.SslPinningCommon));
exports.SslPinning = SslPinning;
//# sourceMappingURL=ssl-pinning.ios.js.map